OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversacion",
    "(Duration %s)" : "(Durada %s)",
    "You attended a call with {user1}" : "Avètz assistit a una sonada amb {user1}",
    "_%n guest_::_%n guests_" : ["%n convidat","%n convidats"],
    "You attended a call with {user1} and {user2}" : "Avètz assistit a una sonada amb {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Avètz assistit a una sonada amb {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Avètz assistit a una sonada amb {user1}, {user2},  {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Avètz assistit a una sonada amb {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n autre","%n autres"],
    "{actor} invited you to {call}" : "{actor} vos a convidat a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Sètz convidat a una <strong>conversacion</strong> o avètz agut una <strong>sonada</strong>",
    "Other activities" : "Autras activitats",
    "Talk" : "Talk",
    "Guest" : "Convidat",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "La benvenguda a Nextcloud Talk !\nDins aquesta conversacion vos informarem a prepaus de las foncionalitats novèlas dins Nextcloud Talk.",
    "New in Talk %s" : "Nòus dins Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge e Safari pòdon ara utilizar la conversacion àudio e vidèo",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Podètz ara notificar totes los participants en publicant « @all » al chat",
    "- You can now mention guests in the chat" : "- Podètz ara mencionar los convidats al chat",
    "- Join the same conversation and call from multiple devices" : "- Participar a la meteissa conversacion e sonada de mantun aparelh estant",
    "- Send voice messages, share your location or contact details" : "- Enviar de messatges vocals, partejar vòstra posicion e detalhs de contactes",
    "There are currently no commands available." : "Cap de comanda pas disponibla pel moment.",
    "The command does not exist" : "La comanda existís pas",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Una error s’es producha en executant la comanda. Volgatz demandar a l’administrator de verificar los jornals.",
    "Talk updates ✅" : "Mesas a jorn Talk ✅",
    "{actor} created the conversation" : "{actor} a creat la conversacion",
    "You created the conversation" : "Avètz creat la conversacion",
    "An administrator created the conversation" : "Un administrator a creat la conversacion",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} a renomenat la conversacion de « %1$s » a « %2$s »",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Avètz renomenat la conversacion de « %1$s » a « %2$s »",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un administrator a renomenat la conversacion de « %1$s » a « %2$s »",
    "{actor} set the description" : "{actor} escriguèt la descripcion",
    "You set the description" : "Avètz escricha la descripcion",
    "An administrator set the description" : "Un administrator escriguèt la descripcion",
    "{actor} removed the description" : "{actor} a tirat la descripcion",
    "You removed the description" : "Avètz tirat la descripcion",
    "An administrator removed the description" : "Un administrator a tirat la descripcion",
    "{actor} started a call" : "{actor} a començat una sonada",
    "You started a call" : "Avètz començat una sonada",
    "{actor} joined the call" : "{actor} a rejonh la sonada",
    "You joined the call" : "Avètz rejonch la sonada",
    "{actor} left the call" : "{actor} a quitat la sonada",
    "You left the call" : "Avètz quitat la sonada",
    "{actor} unlocked the conversation" : "{actor} a desverrolhat la conversacion",
    "You unlocked the conversation" : "Avètz desverrolhat la conversacion",
    "An administrator unlocked the conversation" : "Un administrator a desverrolhat la conversacion",
    "{actor} locked the conversation" : "{actor} a clavat la conversacion",
    "You locked the conversation" : "Avètz clavat la conversacion",
    "An administrator locked the conversation" : "Un administrator a clavat la conversacion",
    "{actor} limited the conversation to the current participants" : "{actor} a limitat la conversacion als participants actuals",
    "You limited the conversation to the current participants" : "Avètz limitat la conversacion als participants actuals",
    "An administrator limited the conversation to the current participants" : "Un administrator a limitat la conversacion als participants actuals",
    "{actor} opened the conversation to registered users" : "{actor} dobriguèt la conversacion als utilizaires enregistrats",
    "You opened the conversation to registered users" : "Dobriretz la conversacion als utilizaires enregistrats",
    "An administrator opened the conversation to registered users" : "Un administrator dobriguèt la conversacion als utilizaires enregistrats",
    "{actor} opened the conversation to registered and guest app users" : "{actor} dobriguèt la conversacion als utilizaires enregistrats",
    "You opened the conversation to registered and guest app users" : "Avètz dobèrt la conversacion als utilizaires enregistrats e als convidats",
    "An administrator opened the conversation to registered and guest app users" : "Un administrator dobriguèt la conversacion als utilizaires enregistrats e als convidats",
    "The conversation is now open to everyone" : "La conversacion es ara dubèrta a tot lo monde",
    "{actor} opened the conversation to everyone" : "{actor} a dubèrta la conversacion a tot lo monde",
    "You opened the conversation to everyone" : "Avètz dobèrta la conversacion a tot lo monde",
    "{actor} restricted the conversation to moderators" : "{actor} a restrench la conversacion als moderators",
    "You restricted the conversation to moderators" : "Avètz restrench la conversacion als moderators",
    "{actor} allowed guests" : "{actor} autorizèt los convidats",
    "You allowed guests" : "Avètz autorizat los convidats",
    "An administrator allowed guests" : "Un administrator autorizèt los convidats",
    "{actor} disallowed guests" : "{actor} interdiguèt los convidats",
    "You disallowed guests" : "Avètz interdich los convidats",
    "An administrator disallowed guests" : "Un administrator desactivèt los convidats",
    "{actor} set a password" : "{actor} a definit un senhal",
    "You set a password" : "Avètz definit un senhal",
    "An administrator set a password" : "Un administrator a definit un senhal",
    "{actor} removed the password" : "{actor} a tirat lo senhal",
    "You removed the password" : "Avètz tirat lo senhal",
    "An administrator removed the password" : "Un administrator a tirat lo senhal",
    "{actor} added {user}" : "{actor} a apondut {user}",
    "You joined the conversation" : "Rejonhètz la conversacion",
    "{actor} joined the conversation" : "{actor} dintra dins la conversacion",
    "You added {user}" : "Avètz apondut {user}",
    "{actor} added you" : "{actor} vos a apondut",
    "An administrator added you" : "Un administrator vos a apondut",
    "An administrator added {user}" : "Un administrator a apondut {user}",
    "You left the conversation" : "Avètz quitat la conversacion",
    "{actor} left the conversation" : "{actor} a quitat la conversacion",
    "{actor} removed {user}" : "{actor} a levat {user}",
    "You removed {user}" : "Avètz levat {user}",
    "{actor} removed you" : "{actor} vos a levat",
    "An administrator removed you" : "Un administrator vos a levat",
    "An administrator removed {user}" : "Un administrator a tirat {user}",
    "{actor} added group {group}" : "{actor} apondèt lo grop {group}",
    "You added group {group}" : "Avètz apondut lo grop {group}",
    "An administrator added group {group}" : "Un administrator apondèt lo grop {group}",
    "{actor} removed group {group}" : "{actor} levèt lo grop {group}",
    "You removed group {group}" : "Avètz levat lo grop {group}",
    "An administrator removed group {group}" : "Un administrator tirèt lo grop {group}",
    "{actor} added circle {circle}" : "{actor} apondèt lo cercle {circle}",
    "You added circle {circle}" : "Avètz apondut lo cercle {circle}",
    "An administrator added circle {circle}" : "Un administrator apondèt lo cercle {circle}",
    "{actor} removed circle {circle}" : "{actor} tirèt lo cercle {circle}",
    "You removed circle {circle}" : "Avètz tirat lo cercle {circle}",
    "An administrator removed circle {circle}" : "Un administrator tirèt lo cercle {circle}",
    "{actor} promoted {user} to moderator" : "{actor} faguèt passar {user} moderator",
    "You promoted {user} to moderator" : "Avètz fach passar {user} moderator",
    "{actor} promoted you to moderator" : "{actor} vos faguèt passar moderator",
    "An administrator promoted you to moderator" : "Un administrator vos faguèt passar moderator",
    "An administrator promoted {user} to moderator" : "Un administrator faguèt passar {user} moderator",
    "{actor} demoted {user} from moderator" : "{actor} retrogradèt {user} de l’estat de moderator",
    "You demoted {user} from moderator" : "Avètz retrogradat {user} de l’estat de moderator",
    "{actor} demoted you from moderator" : "{actor} vos retrogradèt de l’estat de moderator",
    "An administrator demoted you from moderator" : "Un administrator vos retrogradèt de l’estat de moderator",
    "An administrator demoted {user} from moderator" : "Un administrator retrogradèt {user} de l’estat de moderator",
    "{actor} shared a file which is no longer available" : "{actor} partegèt un fichièr qu’es pas pus disponible",
    "You shared a file which is no longer available" : "Partegèretz un fichièr qu'es pas pus disponible",
    "The shared location is malformed" : "L’emplaçament partejat es mal format",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} configurèt Matterbridge per sincronizar aquesta conversacion amb d’autras discussions",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Avètz configurat Matterbridge per sincronizar aquesta conversacion amb d’autras discussions",
    "{actor} updated the Matterbridge configuration" : "{actor} actualizèt la configuracion Matterbridge",
    "You updated the Matterbridge configuration" : "Avètz actualizada la configuracion Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} suprimissèt la configuracion Matterbridge",
    "You removed the Matterbridge configuration" : "Avètz suprimida la configuracion Matterbdrige",
    "{actor} started Matterbridge" : "{actor} a lançat Matterbridge",
    "You started Matterbridge" : "Avètz lançat Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} arrestèt Matterbridge",
    "You stopped Matterbridge" : "Avètz arrestat Matterbridge",
    "{actor} deleted a message" : "{actor} a suprimit un messatge",
    "You deleted a message" : "Avètz suprimit un messatge",
    "{actor} cleared the history of the conversation" : "{actor} escafèt l'istoric de la conversacion",
    "You cleared the history of the conversation" : "Avètz escafat l'istoric de la conversacion",
    "Message deleted by author" : "Messatge suprimit per son autor",
    "Message deleted by {actor}" : "Messatge suprimit per {actor}",
    "Message deleted by you" : "Messatge suprimit per vos",
    "Deleted user" : "Utilizaire suprimit",
    "%s (guest)" : "%s (convidat)",
    "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
    "You tried to call {user}" : "Avètz ensajat de sonar {user}",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Sonada amb %n convidat (Durada {duration})","Sonada amb %n convidats (Durada {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} acabèt la sonada amb %n convidat (Durada {duration})","{actor} acabèt la sonada amb %n convidats (Durada {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} acabèt la sonada amb {user1} (Durada {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} acabèt la sonada amb {user1} e {user2} (Durada {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2} e {user3} (Durada {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2}, {user3}, {user4} {user5} (Durada {duration})",
    "Talk to %s" : "Parlar a %s",
    "File is not shared, or shared but not with the user" : "Fichièr pas partejat, o partejat mas pas a l’utilizaire",
    "No account available to delete." : "Cap de compte pas disponible per la supression.",
    "No image file provided" : "Cap de fichièr imatge provesit",
    "File is too big" : "Fichièr tròp pesuc",
    "Invalid file provided" : "Fichièr provesit invalid",
    "Invalid image" : "Imatge invalid",
    "Unknown filetype" : "filetype desconegut",
    "An error occurred. Please contact your admin." : "Una error s’es producha. Contactatz l’administrator.",
    "Talk mentions" : "Mencions Talk",
    "Write to conversation" : "Escriure dins la conversacion",
    "%s invited you to a conversation." : "%s vos a convidat a una conversacion.",
    "You were invited to a conversation." : "Òm vos a convidat a una conversacion.",
    "Conversation invitation" : "Convit de conversacion",
    "Click the button below to join." : "Clicatz sul boton per participar.",
    "Join »%s«" : "Rejónher « %s »",
    "Dial-in information" : "Entresenhas de sonada",
    "Meeting ID" : "Identificant reünion",
    "Your PIN" : "Vòstre còdi",
    "Password request: %s" : "Senhal requerit : %s",
    "Private conversation" : "Conversacion privada",
    "Deleted user (%s)" : "Utilizaire suprimit (%s)",
    "{user1} shared room {roomName} on {remoteServer} with you" : "{user1} a partejat la sala {roomName} sus {remoteServer} amb vos",
    "{user} in {call}" : "{user} dins {call}",
    "Deleted user in {call}" : "Utilizaire suprimit dins {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) dins {call}",
    "Guest in {call}" : "Convidat dins {call}",
    "{user} sent you a private message" : "{user} vos a enviat un messatge privat",
    "{user} sent a message in conversation {call}" : "{user} a enviat un messatge dins la conversacion {call}",
    "A deleted user sent a message in conversation {call}" : "Un utilizaire suprimit vos envièt un messatge dins la conversacion {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (convidat) mandèt un messatge dins la conversacion {call}",
    "A guest sent a message in conversation {call}" : "Un convidat a enviat un messatge dins la conversacion {call}",
    "{user} replied to your private message" : "{user} a respondut a vòstre messatge privat",
    "{user} replied to your message in conversation {call}" : "{user} a respondut a vòstre messatge dins la conversacion {call}",
    "A deleted user replied to your message in conversation {call}" : "Un utilizaire suprimit a respondut a vòstre messatge dins la conversacion {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (convidat) respondèt a vòstre messatge dins la conversacion {call}",
    "A guest replied to your message in conversation {call}" : "Un convidat respondèt a vòstre messatge dins la conversacion {call}",
    "{user} mentioned you in a private conversation" : "{user} vos mencionèt dins una conversacion privada",
    "{user} mentioned you in conversation {call}" : "{user} vos a mencionat dins la conversacion {call}",
    "A deleted user mentioned you in conversation {call}" : "Un utilizaire suprimit vos a mencionat dins la conversacion {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (convidat) vos a mencionat dins la conversacion {call}",
    "A guest mentioned you in conversation {call}" : "Un convidat vos a mencionat dins la conversacion {call}",
    "View chat" : "Veire lo chat",
    "{user} invited you to a private conversation" : "{user} vos a convidat a una conversacion privada",
    "Join call" : "Rejónher la sonada",
    "{user} invited you to a group conversation: {call}" : "{user} vos a convidat a un conversacion de grop : {call}",
    "Answer call" : "Respondre a l’apèl",
    "{user} would like to talk with you" : "{user} volriá vos parlar",
    "Call back" : "Tornar",
    "A group call has started in {call}" : "Una sonada de grop a començat dins {call}",
    "You missed a group call in {call}" : "Avètz mancat una sonada de grop dins {call}",
    "{email} is requesting the password to access {file}" : "{email} demanda l’accès al fichièr {file}",
    "{email} tried to request the password to access {file}" : "{email} ensagèt de demandar lo senhal per accedir a {file}",
    "Someone is requesting the password to access {file}" : "Qualqu’un demanda lo senhal per accedir a {file}",
    "Someone tried to request the password to access {file}" : "Qualqu’un ensagèt de demandar lo senhal per accedir a {file}",
    "Open settings" : "Dobrir los paramètres",
    "The hosted signaling server is now configured and will be used." : "Lo servidor de senhalament albergat es ara configurat e serà utilizat.",
    "Contact via Talk" : "Contactar via Talk",
    "Open Talk" : "Dobrir la conversacion",
    "Conversations" : "Discussions",
    "Messages" : "Messatges",
    "{user}" : "{user}",
    "Messages in {conversation}" : "Messatges dins {conversation}",
    "{user} in {conversation}" : "{user} dins {conversation}",
    "Messages in other conversations" : "Messatges dins autras conversacions",
    "Something unexpected happened." : "Quicòm d’inesperat s’es produch.",
    "The URL is invalid." : "L’URL es invalida.",
    "An HTTPS URL is required." : "Una URL HTTPS es requerida.",
    "The email address is invalid." : "L’adreça email es invalida.",
    "The language is invalid." : "La lenga es invalida.",
    "The country is invalid." : "Lo país es invalid.",
    "Too many requests are send from your servers address. Please try again later." : "Tròp de requèstas enviadas de vòstras adreça de servidor. Ensajatz mai tard.",
    "Something unexpected happened. Please try again later." : "Quicòm d’inesperat s’es produch. Volgatz ensajar mai tard.",
    "There is no such account registered." : "Cal de tal compte pas enregistrat.",
    "Too many requests are sent from your servers address. Please try again later." : "Tròp de requèstas enviadas de vòstras adreça de servidor. Ensajatz mai tard.",
    "Andorra" : "Andòrra",
    "United Arab Emirates" : "Emirats Arabis Units",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angòla",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "Amèrica, nord",
    "Austria" : "Austria",
    "Australia" : "Austràlia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illas Åland",
    "Azerbaijan" : "Azerbaitjan",
    "Bosnia and Herzegovina" : "Bòsnia e Ercegovina",
    "Barbados" : "Barbada",
    "Bangladesh" : "Bangladèsh",
    "Belgium" : "Bèlgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Barein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sant Bartomieu",
    "Bermuda" : "Bermudas",
    "Brunei Darussalam" : "Sultanat de Brunei",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Botan",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorusia",
    "Belize" : "Belize",
    "Canada" : "Canadà",
    "Cocos (Keeling) Islands" : "Illas Cocos (Keeling)",
    "Central African Republic" : "Centrafrica",
    "Congo" : "Congò",
    "Switzerland" : "Soïssa",
    "Côte d'Ivoire" : "Còsta d'Evòri",
    "Cook Islands" : "Illas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameron",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Còsta Rica",
    "Cuba" : "Cubà",
    "Cabo Verde" : "Cap Verd",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Illa Cristmas",
    "Cyprus" : "Chipre",
    "Czechia" : "Republica Chèca",
    "Germany" : "Alemanha",
    "Djibouti" : "Jiboti",
    "Denmark" : "Danemarc",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Republica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Eqüator",
    "Estonia" : "Estònia",
    "Egypt" : "Egipte",
    "Western Sahara" : "Sahara occidental",
    "Eritrea" : "Eritrèa",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Illas Maldivas",
    "Micronesia, Federated States of" : "Micronesia, Estats Federats de",
    "Faroe Islands" : "Illas Feròe",
    "France" : "França",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Reialme Unit de Grand Bretanha e d’Irlanda del Nòrd",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana francesa",
    "Guernsey" : "Alemanya",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinèa",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinèa Eqüatoriala",
    "Greece" : "Grèça",
    "South Georgia and the South Sandwich Islands" : "Georgia del Sud e las illas Sandwich del Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinèa-Bissau",
    "Guyana" : "Guianà",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Illas de Heard e McDonald",
    "Honduras" : "Hondures",
    "Croatia" : "Croacia",
    "Haiti" : "Aïtí",
    "Hungary" : "Ongria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Territòris britanics de l'ocean indian",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Islàndia",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaïca",
    "Jordan" : "Jordan",
    "Japan" : "Japon",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirghizstan",
    "Cambodia" : "Cambòtja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comòras",
    "Saint Kitts and Nevis" : "Sant Kitts e Nevis",
    "Korea, Democratic People's Republic of" : "Corèa, Republica Populara Democratica de",
    "Korea, Republic of" : "Corea",
    "Kuwait" : "Koweit",
    "Cayman Islands" : "Illas Caiman",
    "Kazakhstan" : "Cazacstan",
    "Lao People's Democratic Republic" : "Laòs",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "St. Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Luxemborg",
    "Latvia" : "Letònia",
    "Libya" : "Libia",
    "Morocco" : "Marròc",
    "Monaco" : "Monegue",
    "Moldova, Republic of" : "Moldàvia",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Sant Martin (francés)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illas Marshall",
    "Macedonia, the former Yugoslav Republic of" : "Republica de Macedònia del Nòrd",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Kanu",
    "Northern Mariana Islands" : "Illas Marianas del Nòrd",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritània",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurici",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "Mexic",
    "Malaysia" : "Malàisia",
    "Mozambique" : "Moçambic",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nòva Caledònia",
    "Niger" : "Nigèr",
    "Norfolk Island" : "Norfòlk, Illa",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Holanda",
    "Norway" : "Norvègia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Novèla Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panamà",
    "Peru" : "Peru",
    "French Polynesia" : "Polinesia francesa",
    "Papua New Guinea" : "Papoa-Nòva Guinèa",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistan",
    "Poland" : "Polonha",
    "Saint Pierre and Miquelon" : "Sant Pèire e Miquelon",
    "Pitcairn" : "Illas Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Estat de Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "La Reünion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federacion russa",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomon",
    "Seychelles" : "Seichèlas",
    "Sudan" : "Sodan",
    "Sweden" : "Suècia",
    "Singapore" : "Singapor",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard e illa Jan Mayen",
    "Slovakia" : "Eslòvac",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "Sant Marin",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sodan del Sud",
    "Sao Tome and Principe" : "São Tomé e Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sant Martin (part neerlandesa)",
    "Syrian Arab Republic" : "Siria",
    "Turks and Caicos Islands" : "Illas Turcas e Caïcas",
    "Chad" : "Chad",
    "French Southern Territories" : "Tèrras australas francesas",
    "Togo" : "Tògo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Tatgiquistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tònga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinitat e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, Província de China",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ucraïna",
    "Uganda" : "Oganda",
    "United States Minor Outlying Islands" : "Illas menoras aluenhadas dels Estats Units d'America",
    "United States of America" : "Estats Units d'America",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Ozbequistan",
    "Holy See" : "Santa Ses",
    "Saint Vincent and the Grenadines" : "Sant Vincenç e las Grenadinas",
    "Venezuela, Bolivarian Republic of" : "República Bolivariana de Venezuela",
    "Virgin Islands, British" : "Illas Verges Britanicas",
    "Virgin Islands, U.S." : "Virgin Islands, U.S.",
    "Viet Nam" : "Vinyes",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemèn",
    "Mayotte" : "Maiòta",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalida data, lo format de data deu èsser YYYY-MM-DD",
    "Conversation not found" : "Conversacion pas trobada",
    "Chat, video & audio-conferencing using WebRTC" : "Messatjariá, conferéncias vidèo e àudio amb WebRTC",
    "Leave call" : "Quitar la sonada",
    "Stay in call" : "Demorar en linha",
    "Duplicate session" : "Duplicar la session",
    "Discuss this file" : "Discutir d’aqueste fichièr",
    "Share this file with others to discuss it" : "Partejar aqueste fichièr amb d’autres per ne discutir",
    "Share this file" : "Partejar aqueste fichièr",
    "Join conversation" : "Rejónher la conversacion",
    "Request password" : "Demandar senhal",
    "Error requesting the password." : "Error en demandant lo senhal.",
    "This conversation has ended" : "La conversacion es acabada",
    "Limit to groups" : "Limitar als grops",
    "Guests can still join public conversations." : "Los convidats pòdon encara rejónher las conversacions publicas.",
    "Limit using Talk" : "Limits d’utilizacion de Talk",
    "Limit creating a public and group conversation" : "Limitar la creacion de grops e publicas de conversacions",
    "Limit creating conversations" : "Limitar la creacion de conversacions",
    "Limit starting a call" : "Limitar l’aviada de sonada",
    "Everyone" : "Tot lo monde",
    "Users and moderators" : "Utilizaires e moderators",
    "Moderators only" : "Moderators solament",
    "Save changes" : "Salvar los cambiaments",
    "Saving …" : "Enregistrament…",
    "Saved!" : "Enregistrat",
    "None" : "Pas cap",
    "User" : "User",
    "Disabled" : "Desactivat",
    "Moderators" : "Moderators",
    "Users" : "Utilizaires",
    "Commands" : "Comandas",
    "Beta" : "Bèta",
    "Name" : "Nom",
    "Command" : "Comanda",
    "Script" : "Escript",
    "Response to" : "Respondre a",
    "Enabled for" : "Activat per",
    "General settings" : "Paramètres generals",
    "Default notification settings" : "Paramètres de notificacion per defaut",
    "Default group notification" : "Notificacion de grop per defaut",
    "Integration into other apps" : "Integracion dins d’autras aplicacions",
    "Allow conversations on files" : "Permetre las conversacions suls fichièrs",
    "Allow conversations on public shares for files" : "Permetre las conversacions suls partiment de fichièrs",
    "All messages" : "Totes los messatges",
    "@-mentions only" : "@-mencions sonque",
    "Off" : "Atudat",
    "URL of this Nextcloud instance" : "URL d’aquesta instància Nextcloud",
    "Email of the user" : "Email de l’utilizaire",
    "Language" : "Lenga",
    "Country" : "País",
    "Status" : "Estatut",
    "Created at" : "Creat lo",
    "Expires at" : "Expira lo",
    "Limits" : "Limits",
    "Pending" : "En espèra",
    "Error" : "Error",
    "Blocked" : "Blocat",
    "Active" : "Activa",
    "Expired" : "Expirat",
    "_%n user_::_%n users_" : ["%n utilizaire","%n utilizaires"],
    "Matterbridge integration" : "Integracion Matterbridge",
    "Enable Matterbridge integration" : "Activar l’integracion Matterbridge",
    "Downloading …" : "Telecargament…",
    "Install Talk Matterbridge" : "Installar Talk Matterbridge",
    "Installed version: {version}" : "Version installada : {version}",
    "An error occurred while installing the Talk Matterbridge. Please install it manually." : "Una error s’es producha pendent l’installacion de Talk Matterbridge. Volgatz l’installar manualament.",
    "SIP configuration" : "Configuracion SIP",
    "SIP configuration is only possible with a high-performance backend." : "La configuracion SIP es sonque possibla amb un backend de nauta performança",
    "Enable SIP configuration" : "Activar la configuracion SIP",
    "Shared secret" : "Secret partejat",
    "Phone number (Country)" : "Numèro de telefòn (País)",
    "Validate SSL certificate" : "Validar lo certificat SSL",
    "Delete this server" : "Suprimir aqueste servidor",
    "Status: Checking connection" : "Estat : verificacion de la connexion",
    "OK: Running version: {version}" : "OK : execucion de la version : {version}",
    "Error: Cannot connect to server" : "Error : connexion impossibla al servidor",
    "Error: Server did not respond with proper JSON" : "Error: lo servidor a pas respondut amb un JSON corrèct",
    "Error: Server responded with: {error}" : "Error : lo servidor a respondut : {error}",
    "Error: Unknown error occurred" : "Error : una error desconeguda s'es produsida",
    "Saved" : "Enregistrat",
    "Add a new server" : "Apondre un servidor novèl",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Es forçadament recomandat de configurar a cache distribuit pendent l’utilizacion de Nextcloud Talk amb un back-end de fòrt rendiment.",
    "Don't warn about connectivity issues in calls with more than 4 participants" : "Avertir pas dels problèmas de connectivitat dins las sonadas de mai de 4 participants",
    "STUN server URL" : "URL servidor STUN",
    "STUN servers" : "Servidors STUN",
    "TURN server schemes" : "Esquèmas servidor TURN",
    "{option1} and {option2}" : "{option1} e {option2}",
    "{option} only" : "{option} sonque",
    "TURN server URL" : "URL servidor TURN",
    "TURN server secret" : "Secrèt servidor TURN",
    "TURN server protocols" : "Protocòls servidor TURN",
    "{schema} scheme must be used with a domain" : "l’esquèma {schema} deu èsser utilizat amb un domeni",
    "Test this server" : "Ensajar aqueste servidor",
    "TURN servers" : "Servidor TURN",
    "Web server setup checks" : "Verificacions de configuracion del servidor Web",
    "Failed" : "Fracàs",
    "OK" : "D’acòrdi",
    "Checking …" : "Verificacion…",
    "{nickName} raised their hand." : "{nickName} a levat la man.",
    "A participant raised their hand." : "Un participant a levat la man.",
    "Previous page of videos" : "Pagina de vidèos precedenta",
    "Next page of videos" : "Pagina de vidèos seguenta",
    "Copy link" : "Copiar lo ligam",
    "Connecting …" : "Connexion…",
    "Waiting for others to join the call …" : "En espèra que d’autres arriben…",
    "You can invite others in the participant tab of the sidebar" : "Podètz convidar d’autre monde amb l’onglet dels participants de la barra laterala",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Podètz convidar d’autre monde amb l’onglet dels participants de la barra laterala o partejar aqueste ligam per los convidar !",
    "Share this link to invite others!" : "Partejatz aqueste ligam per convidar mai de monde !",
    "Conversation link copied to clipboard." : "Ligam de conversacion copiat al quichapapièrs.",
    "The link could not be copied." : "Impossible de copiar lo ligam.",
    "Dismiss" : "Regetar",
    "Show your screen" : "Partejar l’ecran",
    "Stop screensharing" : "Arrestar partiment d’ecran",
    "Lower hand (R)" : "Baissar la man (R)",
    "More actions" : "Mai d’accions",
    "Devices settings" : "Paramètres dels periferics",
    "Raise hand (R)" : "Levar la man (R)",
    "Blur background" : "Rèireplan trebol",
    "Disable background blur" : "Desactivar lo rèireplan trebol",
    "You are not allowed to enable audio" : "Avètz pas l'autorizacion per activar l’àudio",
    "No audio" : "Cap d’àudio",
    "Mute audio (M)" : "Copar lo son (M)",
    "Unmute audio (M)" : "Restablir lo son (M)",
    "Mute audio" : "Copar lo son",
    "Unmute audio" : "Restablir lo son",
    "You are not allowed to enable video" : "Avètz pas l'autorizacion per activar la vidèo",
    "No camera" : "Cap de camèra",
    "Disable video (V)" : "Desactivar la vidèo (V)",
    "Enable video (V)" : "Activar la vidèo (V)",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Activar la vidèo (V) - La connexion serà interrompuda brèvament pendent l’activacion de la vidèo pel primièr còp",
    "Disable video" : "Desactivar la vidèo",
    "Enable video" : "Activar la vidèo",
    "You are not allowed to enable screensharing" : "Avètz pas l'autorizacion per activar lo partiment d’ecran",
    "No screensharing" : "Cap de partiment d’ecran",
    "Screensharing options" : "Opcion de partiment d’ecran",
    "Enable screensharing" : "Activar lo partiment d’ecran",
    "Bad sent video and screen quality." : "Marrida vidèo enviada e qualitat d’ecran.",
    "Bad sent screen quality." : "Marrida qualitat d’ecran enviada.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo pendent un partiment d’ecran.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo pendent un partiment d’ecran.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
    "Disable screenshare" : "Desactivar lo partiment d’ecran",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas.",
    "Speaker view" : "Vista parlaire",
    "Grid view" : "Vista en grasilha",
    "Screen sharing is not supported by your browser." : "Vòstre navegador pren pas en carga lo partiment d’ecran.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís que la pagina siá cargada via HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís un cargament via HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
    "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran.",
    "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
    "Back" : "Retorn",
    "Access to camera was denied" : "L’accès a la camèra es estat refusat",
    "Error while accessing camera: It is likely in use by another program" : "Error d’accès a la camèra : poiriá arribar qu’un autre programa l’utilize",
    "Error while accessing camera" : "Error pendent l’accès a la camèra",
    "You have been muted by a moderator" : "Un moderator vos a amudit",
    "You" : "Vos",
    "Connection could not be established …" : "Establiment impossible de la connexion…",
    "Connection was lost and could not be re-established …" : "Connexion perduda e restabliment impossibla…",
    "Connection could not be established. Trying again …" : "Establiment impossible… Novèl ensag…",
    "Connection lost. Trying to reconnect …" : "Connexion perduda. Ensag de reconnexion…",
    "Connection problems …" : "Problèmas de connexion…",
    "Show screen" : "Far veire l’ecran",
    "Mute" : "Mut",
    "Stop following" : "Quitar de seguir",
    "Conversation messages" : "Messatges de conversacion",
    "Post message" : "Publicar messatge",
    "You need to be logged in to upload files" : "Devètz èsser autentificat per enviar de fichièrs",
    "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
    "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
    "Call in progress" : "Sonada en cors",
    "Favorite" : "Favorit",
    "All permissions" : "Totas las permissions",
    "Restricted" : "Restrencha",
    "Advanced permissions" : "Permissions avançadas",
    "Edit permissions" : "Modificar las autorizacions",
    "Default permissions modified for {conversationName}" : "Permissions per defaut modificadas per {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Las permissions per defaut se podiá pas modificar {conversationName}",
    "Conversation settings" : "Paramètres de conversacion",
    "Description" : "Descripcion",
    "Enter a description for this conversation" : "Picatz una descripcion per aquesta conversacion",
    "Notifications" : "Notificacions",
    "Device check" : "Verificacion de periferic",
    "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
    "Guests access" : "Accès convidat",
    "Participants permissions" : "Permissions dels participants",
    "Meeting settings" : "Paramètres de reünion",
    "Matterbridge" : "Matterbridge",
    "Danger zone" : "Zòna perilhosa",
    "Error while updating conversation description" : "Error pendent l’actualizacion de la descripcion de la conversacion",
    "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
    "Leave conversation" : "Quitar la conversacion",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Un còp quitada, per tornar a un conversacion tampada, cal un convit. Una conversacion dubèrta es totjorn accessibla.",
    "Delete conversation" : "Suprimir la conversacion",
    "Permanently delete this conversation." : "Suprimir permanent aquesta conversacion",
    "Delete chat messages" : "Suprimir los messatges del chat",
    "Permanently delete all the messages in this conversation." : "Suprimir per totjorn totes los messatges d’aquesta conversacion.",
    "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
    "Error while deleting conversation" : "Error pendent la supression de la conversacion",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Volètz vertadièrament suprimir totes los messatges dins « {displayName} » ?",
    "Delete all chat messages" : "Suprimir totes los messatges del chat",
    "Error while clearing chat history" : "Error pendent l’escafament de l’istoric del chat",
    "Allow guests to use a public link to join this conversation." : "Permetre als convidats d’utilizar un ligam public per rejónher aquesta conversacion.",
    "Allow guests" : "Autorizar los convidats",
    "Set a password to restrict who can use the public link." : "Definir lo senhal per restrénher qual pòt utilizar lo ligam public.",
    "Password protection" : "Protegir via senhal",
    "Enter a password" : "Picatz un senhal",
    "Save password" : "Enregistrar lo senhal",
    "Copy conversation link" : "Copiar lo ligam de conversacion",
    "Resend invitations" : "Tornar enviar las invitacions",
    "Conversation password has been saved" : "Lo senhal de conversacion es estat enregistrat",
    "Conversation password has been removed" : "Lo senhal de conversacion es estat suprimit",
    "Error occurred while saving conversation password" : "Error pendent l'enregistrament del senhal de la conversacion",
    "Error occurred while allowing guests" : "Error en autorizant los convidats",
    "Error occurred while disallowing guests" : "Error en autorizant pas mai los convidats",
    "Invitations sent" : "Invitacions enviadas",
    "Error occurred when sending invitations" : "Error en enviant las invitacions",
    "Open conversation to registered users" : "Dobrir la conversacion als utilizaires enregistrats",
    "This conversation will be shown in search results" : "Aquesta conversacion serà mostrada als resultats de recèrca",
    "Error occurred when opening or limiting the conversation" : "Error en dobrissent o limitant la conversacion",
    "Enabling the lobby only allows moderators to post messages." : "Activar la sala d’espèra permet als moderators de publicar de messatges.",
    "This will also remove non-moderators from the ongoing call." : "Aquò tirarà tanben los non moderators de la sonada en cors.",
    "Enable lobby" : "Activar la sala d’espèra",
    "After the time limit the lobby will be automatically disabled." : "Aprèp la limita de temps la sala d’espèra serà automaticament desactivada.",
    "Meeting start time" : "Ora de debuta de la conferéncia",
    "Start time (optional)" : "Ora de debuta (opcional)",
    "Error occurred when restricting the conversation to moderator" : "Error pendent la restriccion de la conversacion al moderator",
    "Error occurred when opening the conversation to everyone" : "Error pendent la dubertura de la conversacion a tot lo monde",
    "Start time has been updated" : "L'ora de debuta es estada actualizada",
    "Error occurred while updating start time" : "Error pendent la mesa a jorn de l’ora de debuta",
    "Locking the conversation prevents anyone to post messages or start calls." : "Lo verrolhatge de la conversacion empacha qual que siá de publicar de messatges o començar de sonadas.",
    "This will also terminate the ongoing call." : "Aquò acabarà tanben la sonada en cors.",
    "Lock conversation" : "Verrolhar la conversacion",
    "Error occurred when locking the conversation" : "Error pendent lo verrolhatge de la conversacion",
    "Error occurred when unlocking the conversation" : "Error pendent lo desverrolhatge de la conversacion",
    "Save" : "Salvar",
    "Edit" : "Modificar",
    "More information" : "Mai d’informacions",
    "Delete" : "Suprimir",
    "More info on Matterbridge" : "Mai d’info sus Matterbridge",
    "Enable bridge" : "Activar lo pont",
    "Show Matterbridge log" : "Veire los jornals de Matterbridge",
    "Nextcloud URL" : "URL Nextcloud",
    "Nextcloud user" : "Utilizaire Nextcloud",
    "User password" : "Senhal utilizaire",
    "Talk conversation" : "Conversacion Talk",
    "Matrix server URL" : "URL servidor Matrix",
    "Matrix channel" : "Cadena Matrix",
    "Mattermost server URL" : "URL servidor Mattermost",
    "Mattermost user" : "Utilizaire Mattermost",
    "Team name" : "Nom de la còla",
    "Channel name" : "Nom de la cadena",
    "Rocket.Chat server URL" : "URL del servidor Rocket.Chat",
    "User name or email address" : "Nom d’utilizaire o adreça email",
    "Password" : "Senhal",
    "Rocket.Chat channel" : "Canal Rocket.Chat",
    "Skip TLS verification" : "Passar la verificacion TLS",
    "Zulip server URL" : "URL servidor Zulip",
    "Bot user name" : "Nom d’utilizaire robòt",
    "Bot API key" : "Clau d’API robòt",
    "Zulip channel" : "Canal Zulip",
    "API token" : "Geton API",
    "Slack channel" : "Canal Slack",
    "Server ID or name" : "ID o nom del servidor",
    "Channel ID or name" : "ID o nom del canal",
    "Channel" : "Cadena",
    "Login" : "Login",
    "Chat ID" : "ID del chat",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL servidor IRC (per exemple chat.freenode.net:6667)",
    "Nickname" : "Escais",
    "Connection password" : "Senhal de connexion",
    "IRC channel" : "Cadena IRC",
    "Channel password" : "Senhal de cadena",
    "NickServ nickname" : "Nom d’utilizaire NickServ",
    "NickServ password" : "Senhal NickServ",
    "Use TLS" : "Utilizar TLS",
    "Use SASL" : "Utilizar SASL",
    "Tenant ID" : "ID Tenant",
    "Client ID" : "ID client",
    "Team ID" : "ID Team",
    "Thread ID" : "ID fial",
    "XMPP/Jabber server URL" : "URL servidor XMPP/Jabber",
    "MUC server URL" : "URL servidor MUC",
    "Jabber ID" : "ID Jabber",
    "unknown state" : "estat desconegut",
    "running" : "en cors d'execucion",
    "not running" : "pas en execucion",
    "Bridge saved" : "Pont enregistrat",
    "Chat messages" : "Messatges",
    "Calls" : "Sonadas",
    "Notify about calls in this conversation" : "Notificar las sonadas d’aquesta conversacion",
    "Cancel editing description" : "Anullar la modificacion de la descripcion",
    "Submit conversation description" : "Enviar la descripcion de la conversacion",
    "Edit conversation description" : "Editar la descripcion de la conversacion",
    "Camera and microphone check" : "Verificacion de camèra e de microfòn",
    "Choose devices" : "Causir periferics",
    "Always show this dialog before joining a call in this conversation." : "Totjorn mostrar aquesta fenèstra abans de rejónher una sonada d’aquesta conversacion.",
    "Mark as read" : "Marcar coma legit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Joining conversation …" : "Dintra dins la conversacion…",
    "You: {lastMessage}" : "Vos : {lastMessage}",
    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
    "No matches" : "Cap de resultat correspond pas",
    "Conversation list" : "Lista de conversacion",
    "Open conversations" : "Dobrir las conversacions",
    "Loading" : "Loading",
    "No search results" : "pas cap de resultats de recèrca",
    "Groups" : "Gropes",
    "Circles" : "Cercles",
    "Talk settings" : "Paramètres Talk",
    "Users and groups" : "Utilizaires e grops",
    "Users and circles" : "Utilizaires e cercles",
    "Groups and circles" : "Grops e cercles",
    "Other sources" : "Autras fonts",
    "An error occurred while performing the search" : "Una error s'es producha en realizant la recèrca",
    "Creating your conversation" : "Creacion de vòstra conversacion",
    "All set" : "Tot es prèst",
    "Error while creating the conversation" : "Error pendent la creacion de la conversacion",
    "Link copied to the clipboard!" : "Ligam copiat al quichapapièrs !",
    "Create a new group conversation" : "Crear una conversacion de grop novèla",
    "Password protect" : "Protegir per un senhal",
    "Create conversation" : "Crear conversacion",
    "Add participants" : "Apondre participants",
    "Close" : "Tampar",
    "Choose a password" : "Causir un senhal",
    "Search participants" : "Cercar participants",
    "Conversation name" : "Nom de conversacion",
    "Allow guests to join via link" : "Permetre als convidats de rejónher via ligam",
    "Search conversations or users" : "Cercar de conversacions o utilizaires",
    "You are currently waiting in the lobby" : "Sètz a esperar dins la sala d’espèra",
    "The meeting will start soon" : "La conferéncia començarà lèu",
    "This meeting is scheduled for {startTime}" : "La conferéncia es planificada per {startTime}",
    "No microphone available" : "Cap de microfòn pas disponible",
    "Select microphone" : "Causir microfòn",
    "No camera available" : "Cap de camèra pas disponibla",
    "Select camera" : "Causir una camèra",
    "Reply" : "Respondre",
    "Reply privately" : "Respondre en privat",
    "Copy message link" : "Copiar ligam messatge",
    "Mark as unread" : "Marcar coma pas legit",
    "Go to file" : "Anar al fichièr",
    "Forward message" : "Transferir lo messatge",
    "Unread messages" : "Messatges pas legits",
    "Sending message" : "Mandadís del messatge",
    "Message sent" : "Messatge mandat",
    "Message read by everyone who shares their reading status" : "Messatge legit per tot lo monde que partejan lo estatut de lectura",
    "Not enough free space to upload file" : "Pas pro d’espaci liure per enviar lo fichièr",
    "You are not allowed to share files" : "Avètz pas lo drech de partejar de fichièrs",
    "You cannot send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
    "Deleting message" : "Supression del messatge",
    "Message deleted successfully" : "Messatge corrèctament suprimit",
    "Message could not be deleted because it is too old" : "Lo messatge a pas pogut èsser suprimit perque es tròp ancian",
    "Only normal chat messages can be deleted" : "Sonque los messatges de chat normal pòdon èsser suprimits",
    "An error occurred while deleting the message" : "Error pendent la supression del messatge",
    "Message link copied to clipboard." : "Ligam del messatge copiat al quichapapièrs.",
    "Your browser does not support playing audio files" : "Vòstre navegador pren pas en carga la lectura dels fichièrs àudio",
    "Contact" : "Contacte",
    "{stack} in {board}" : "{stack} dins {board}",
    "Remove {fileName}" : "Suprimir {fileName}",
    "The message has been forwarded to {selectedConversationName}" : "Lo messatge es estat transferit a {selectedConversationName}",
    "Go to conversation" : "Anar a la conversacion",
    "Choose a conversation to forward the selected message." : "Causir una conversacion destinària del messatge seleccionat.",
    "Error while forwarding message" : "Error en transferissent lo messatge",
    "Open this location in OpenStreetMap" : "Dobrir aquesta posicion dins OpenStreetMap",
    "Scroll to bottom" : "Desfilar enbàs",
    "Today" : "Uèi",
    "Yesterday" : "Ièr",
    "Record voice message" : "Enregistrar messatge vocal",
    "End recording and send" : "Acabar àudio e enviar",
    "Dismiss recording" : "Anullar l’enregistrament",
    "Access to the microphone was denied" : "L’accès al microfòn es estat refusat",
    "Microphone either not available or disabled in settings" : "Microfòn siá indisponible o desactivat dins los paramètres",
    "Error while recording audio" : "Error en enregistrant l’àudio",
    "Talk recording from {time} ({conversation})" : "Enregistrament Talk a partir de {time} ({conversation})",
    "Share files to the conversation" : "Partejar de fichièrs dins la conversacion",
    "Upload new files" : "Enviar fichièrs novèls",
    "Share from Files" : "Partejar a partir dels Fichièrs",
    "Add emoji" : "Apondre emoji",
    "Send message" : "Enviar un messatge",
    "File to share" : "Fichièr de partejar",
    "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
    "Write message, @ to mention someone …" : "Escriure un messatge, @ per mencionar qualqu’un…",
    "Invalid path selected" : "Camin seleccionat invalid",
    "Start a call" : "Començar una sonada",
    "Skip the lobby" : "Passar la sala d’espèra",
    "Enable the microphone" : "Activar lo microfòn",
    "Enable the camera" : "Activar la camèra",
    "Share the screen" : "Partejar l’ecran",
    "Update permissions" : "Actualizar las autorizacions",
    "Updating permissions" : "Actualizacion de las permissions",
    "In this conversation <strong>{user}</strong> can:" : "Dins aquesta conversacion <strong>{user}</strong> pòt :",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Modificar las permissions per defaut dels participants dins <strong>{conversationName}</strong>",
    "Disable lobby" : "Desactivar la sala d’espèra",
    "moderator" : "moderator",
    "bot" : "robòt",
    "guest" : "convidat",
    "Reset custom permissions" : "Reïnicializar las permissions personalizadas",
    "Remove all permissions" : "Suprimir totas las permissions",
    "Resend invitation" : "Renviar invitacion",
    "Remove group and members" : "Levar de grops e membres",
    "Remove participant" : "Tirar participant",
    "Settings for participant \"{user}\"" : "Paramètres pel participant « {user} »",
    "Add participant \"{user}\"" : "Apondre participant « {user} »",
    "Participant \"{user}\"" : "Participant « {user} »",
    "Joined with audio" : "Rejonhèt amb l’àudio",
    "Joined with video" : "Rejonhèt amb vidèo",
    "Joined via phone" : "Rejonhèt via telefòn",
    "Raised their hand" : "Levèt la man",
    "Invitation was sent to {actorId}." : "Invitacion enviada a {actorId}.",
    "Could not send invitation to {actorId}" : "Mandadís impossible del convit a {actorId}",
    "Permissions granted to {displayName}" : "Autorizacions acordadas a {displayName}",
    "Permissions removed for {displayName}" : "Permissions suprimidas per {displayName}",
    "Permissions set to default for {displayName}" : "Permissions definidas a defaut per {displayName}",
    "Permissions modified for {displayName}" : "Permissions modificadas per {displayName}",
    "Add users" : "Apondre utilizaires",
    "Add groups" : "Apondre grops",
    "Add emails" : "Apondre emails",
    "Add circles" : "Apondre cercles",
    "Add federated users" : "Apondre d’utilizaires federats",
    "Searching …" : "Recèrca…",
    "No results" : "Pas cap de resultat",
    "Search for more users" : "Cercar mai d’utilizaires",
    "Add users, groups or circles" : "Apondre utilizaires, grops o cercles",
    "Add users or groups" : "Add users or groups",
    "Add users or circles" : "Apondre utilizaires o cercles",
    "Add groups or circles" : "Apondre grops o cercles",
    "Add other sources" : "Apondre d'autras fonts",
    "Participants" : "Participants",
    "Search or add participants" : "Cercar o apondre participants",
    "An error occurred while adding the participants" : "Una error s’es producha en ajustant los participants",
    "Chat" : "Messatjariá",
    "Details" : "Detalhs",
    "Settings" : "Paramètres",
    "Participants ({count})" : "Participants ({count})",
    "Meeting ID: {meetingId}" : "ID reünion : {meetingId}",
    "Your PIN: {attendeePin}" : "Vòstre PIN : {attendeePin}",
    "Display name: " : "Nom d’afichatge :",
    "Attachments folder" : "Dossièr de pèças-juntas",
    "Privacy" : "Confidencialitat",
    "Sounds" : "Sons",
    "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
    "Sounds can currently not be played in Safari browser and iPad and iPhone devices due to technical restrictions by the manufacturer." : "Los sons pòdon pas èsser legits dins lo navegador Safari e los aparelhs iPad e iPhone a causa d’una restriccion tecnica del fabricant.",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
    "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
    "Search" : "Search",
    "Shortcuts while in a call" : "Acorchis pendent una sonada",
    "Camera on and off" : "Vidèo activada/desactivada",
    "Microphone on and off" : "Microfòn activat/desactivat",
    "Space bar" : "barra d’espaci",
    "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
    "Raise or lower hand" : "Levar o baissar la man",
    "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
    "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
    "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
    "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
    "Error while setting read status privacy" : "Error lor de definicion de la confidencialitat de l'estatut",
    "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
    "Sounds setting saved" : "Paramètres de son enregistrats",
    "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
    "End meeting for all" : "Acabar la conferéncia per totes",
    "Start call" : "Començar sonada",
    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
    "You will be able to join the call only after a moderator starts it." : "Poiretz sonque participar a la sonada un còp qu'un moderator l'aja començada.",
    "Conversation actions" : "Accions de conversacion",
    "Toggle fullscreen" : "Bascular en mòde ecran complet",
    "Rename conversation" : "Renomenar la conversacion",
    "Mute others" : "Copar lo son dels autres",
    "Exit fullscreen (F)" : "Quitar plen ecran (F)",
    "Fullscreen (F)" : "Plen ecran (F)",
    "You have new unread messages in the chat." : "Avètz un messatge pas legit al chat.",
    "You have been mentioned in the chat." : "Qualqu’un vos a mencionat al chat.",
    "Send" : "Mandar",
    "Add more files" : "Apondre mai de fichièrs",
    "No unread mentions" : "Cap de mencion pas legida",
    "Say hi to your friends and colleagues!" : "Saludatz vòstres amics e collègas !",
    "Start a conversation" : "Començar una conversacion",
    "You were mentioned" : "Qualqu’un vos a mencionat",
    "Message without mention" : "Messatge sens mencion",
    "Mention myself" : "Me mencionar",
    "Mention room" : "Mencionar la sala",
    "The conversation does not exist" : "La conversacion existís pas",
    "Join a conversation or start a new one!" : "Rejonhètz una conversacion o creatz-ne una !",
    "No conversations found" : "Cap de conversacion pas trobada",
    "Select conversation" : "Seleccionar una conversacion",
    "Link to a conversation" : "Ligam cap a la conversacion",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Avètz rejonch la conversacion dins una autra fenèstra o periferic. Aquò es actualament pas pres en cargar per Nextcloud Talk doncas aquesta session es estada tampada.",
    "Join a conversation or start a new one" : "Rejónher una conversacion o ne crear una",
    "Post to a conversation" : "Publicar dins una conversacion",
    "Post to conversation" : "Publicar a la conversacion",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
    "Calls are not supported in your browser" : "Vòstre navegador pren pas encarga las sonadas",
    "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
    "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
    "Error while accessing microphone" : "Error pendent l’accès al microfòn",
    "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
    "An error occurred while fetching the participants" : "Una error s’es producha en recuperant los participants",
    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
    "Do not disturb" : "Me desrengar pas",
    "Away" : "Absent",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "Error while clearing conversation history" : "Error pendent escafament de l’istoric de la conversacion",
    "Not enough free space to upload file \"{fileName}\"" : "Pas pro d’espaci liure per enviar lo fichièr « {fileName} »",
    "Error while uploading file \"{fileName}\"" : "Error en enviant lo fichièr « {fileName} »",
    "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
    "Could not post message: {errorMessage}" : "Fracàs de la publicacion : {errorMessage}",
    "Failed to join the conversation. Try to reload the page." : "Impossible de rejónher la conversacion. Ensajatz de recargar la pagina.",
    "Join here" : "Rejónher aquí",
    "Leave this page" : "Quitar aquesta pagina",
    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
    "Sending signaling message has failed." : "Lo mandadís de messatge de senhalament a pas reüssit.",
    "Lost connection to signaling server. Trying to reconnect." : "Connexion perduda al servidor de senhalament. Ensag de reconnexion.",
    "Lost connection to signaling server. Try to reload the page manually." : "Connexion perduda al servidor de senhalament. Ensajatz de recargar la pagina manualament.",
    "Establishing signaling connection is taking longer than expected …" : "L’establiment de la connexion de senhalizacion pren mai de temps que previst…",
    "Failed to establish signaling connection. Retrying …" : "Fracàs de l’establiment de la connexion de senhalizacion. Novèl ensag…",
    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Fracàs de l’establiment de la connexion de senhalizacion. Quicòm pòt èsser maridament configurat costat servidor.",
    "Default" : "Defaut",
    "Microphone {number}" : "Microfòn {number}",
    "Camera {number}" : "Camèra {number}",
    "Speaker {number}" : "Naut-parlaire {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Sembla que parlatz mentre que lo son es copat, mercés de vos restablir lo son per que vos entendan los autres",
    "Access to microphone & camera is only possible with HTTPS" : "L’accès al microfòn e a la camèra es sonque possibla amb HTTPS",
    "Please move your setup to HTTPS" : "Mercés de passar vòstra configuracion al HTTPS",
    "Access to microphone & camera was denied" : "L’accès al microfòn e a la camèra es estat refusat",
    "WebRTC is not supported in your browser" : "Vòstre navegador pren pas en carga lo WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Volgatz utilizar un navegador diferent coma Firefox o Chrome",
    "Error while accessing microphone & camera" : "Error pendent l’accès al microfòn e a la camèra",
    "This conversation is password-protected" : "Aquesta conversacion es protegida per senhal",
    "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
    "Specify commands the users can use in chats" : "Indicar las comandas que los utilizaires pòdon utilizar als chats",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Lo servidor TURN es utilizat per desviar lo trafic dels participants darrièr un parafuòc.",
    "Signaling servers" : "Servidors de senhalizacion",
    "%s Talk on your mobile devices" : "%sTalk on vòstres aparelhs mobiles",
    "Join conversations at any time, anywhere, on any device." : "Participatz a las conversacion quand volètz, d’ont volètz, sus tot aparelh.",
    "Android app" : "Aplicacion Android",
    "iOS app" : "Aplicacion iOS",
    "{actor} set the description to \"%1$s\"" : "{actor} a definit la descripcion « %1$s »",
    "You set the description to \"%1$s\"" : "Avètz definit la descripcion « %1$s »",
    "An administrator set the description to \"%1$s\"" : "Un administrator a definit la descripcion « %1$s »",
    "{actor} updated the Matterbridge configuration." : "{actor} metèt a jorn la configuracion de Matterbridge",
    "You updated the Matterbridge configuration." : "Avètz mes a jorn la configuracion de Matterbridge",
    "{actor} removed the Matterbridge configuration." : "{actor} suprimiguèt la configuracion de Matterbridg",
    "You removed the Matterbridge configuration." : "Avètz tirada la configuracion de Matterbridge.",
    "{actor} started Matterbridge." : "{actor} lancèt Matterbridge.",
    "You started Matterbridge." : "Avètz lançat Matterbridge.",
    "{actor} stopped Matterbridge." : "{actor} arrestèt Matterbridge.",
    "You stopped Matterbridge." : "Avètz arrestat Matterbridge.",
    "E-mail of the user" : "E-mail de l’utilizaire",
    "Error: Can not connect to server" : "Error : connexion impossibla al servidor",
    "Share whole screen" : "Partejar l’ecran complet",
    "Share a single window" : "Partejar sonque una fenèstra",
    "Lower hand" : "Baissar la man",
    "Raise hand" : "Levar la man",
    "Mute audio (m)" : "Copar lo son (m)",
    "Unmute audio (m)" : "Restablir lo son (m)",
    "Disable video (v)" : "Desactivar la vidèo (v)",
    "Enable video (v)" : "Activar la vidèo (v)",
    "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
    "Error while accessing camera: it is likely in use by another program" : "Error d’accès a la camèra : poiriá arribar qu’un autre programa l’utiliza",
    "User name or e-mail address" : "Nom d’utilizaire o adreça electronica",
    "Conversation \"{conversationName}\"" : "Conversacion « {conversationName} »",
    "Settings for conversation \"{conversationName}\"" : "Paramètres per la conversacion « {conversationName} »",
    "Chat notifications" : "Notificacions de chat",
    "Allow guests to join via link " : "Permetre als convidats de rejónher via ligam",
    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Sètz a esperar dins la sala d’espèra. Aquesta conferéncia es planificada per {startTime}",
    "Microphone" : "Microfòn",
    "Camera" : "Camèra",
    "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
    "Remove" : "Suprimir",
    "[Unknown username]" : "[utilizaire desconegut]",
    "Add a description for this conversation" : "Apondètz una descripcion per aquesta conversacion",
    "Video on and off" : "Vidèo activada/desactivada",
    "Choose in which folder attachments should be saved." : "Causir dins quin dossièr las pèças juntas devon èsser enregistradas.",
    "Exit fullscreen (f)" : "Sortir del ecran complèt (f)",
    "Fullscreen (f)" : "Ecran complèt (f)",
    "Set the notification level for the current conversation. This will affect only the notifications you receive." : "Definir lo nivèl de notificacion per la conversacion actuala. Afectarà sonque las notificacions que recebètz."
},
"nplurals=2; plural=(n > 1);");
